/* OGMDvd - A wrapper library around libripread
 * Copyright (C) 2004-2009 Olivier Rolland <billl@users.sourceforge.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef __OGMRIP_GTK_H__
#define __OGMRIP_GTK_H__

#include <ogmrip-helper.h>

#include <ogmrip-gconf-settings.h>

#include <ogmrip-options-plugin.h>

#include <ogmrip-source-chooser-widget.h>
#include <ogmrip-chooser-list.h>
#include <ogmrip-chapter-list.h>

#endif /* __OGMRIP_GTK_H__ */

